@@ -3,7 +3,7 @@ sortScore.default <-
     
     options(warn=-1)
     
-    res = sortScore.main(x, score)
+    res = sortScore.main(x = x, score = score)
     res$call = match.call()
     class(res) = c("sortScore" , "dLagM")
     res
